using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[CreateAssetMenu(fileName = "New Audio Data", menuName = "Audio/AudioData")]
public class AudioData : ScriptableObject
{
    [SerializeField, Tooltip("When this AudioData is played, 1 clip will be picked at random and played. " +
    "\n\nSet Size to how many audio clips there are to pick from.")]
    private List<AudioClip> clips = null;

    public AudioClip GetRandomClip()
    {
        if (clips.Count > 0)
        {
            int index = Random.Range(0, clips.Count - 1);

            return clips[index];
        }
        return null;
    }

    public float Play(AudioSource source)
    {
        AudioClip clip = GetRandomClip();
        if (clip != null)
        {
            source.PlayOneShot(clip);
            return clip.length;
        }
        else
        {
            return 0;
        }
    }
}
