using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class EnemyMain : MonoBehaviour
{
    [SerializeField]
    private EnemyMovement movement = null;

    [SerializeField]
    private EnemyAudioController audioController = null;

    [SerializeField]
    private VisionCone enemyCone = null;

    [SerializeField]
    private Collider2D enemyCollider = null;

    [SerializeField]
    private int currencyValue = 150;

    // Start is called before the first frame update
    void Start()
    {
        enemyCone.OnSeePlayerChange += OnSeePlayerChange;
        enemyCone.OnPictureTaken += OnPictureTaken;
    }

    public void EnterGameArea()
    {
        // Enable colliders and vision cone
        enemyCollider.gameObject.layer = 8; // "enemy" physics layer
        enemyCone.gameObject.SetActive(true);
        movement.GenerateNewTargetInGameArea();
    }

    // Returns how much currency is earned
    public int GetSpooked(Vector3 spookPosition)
    {
        // Can only be spooked if player is not in the vision cone
        if (!enemyCone.playerInCone)
        {
            // Disable colliders and vision cone
            enemyCollider.gameObject.layer = 9; // "fleeing" physics layer
            enemyCone.gameObject.SetActive(false);

            // Run away from spook
            movement.RunAway(spookPosition);
            audioController.PlayRunAway();

            return currencyValue;
        }

        return 0;
    }

    private void OnSeePlayerChange(bool takingPhoto)
    {
        // If we spotted player, hold still to take a picture
        movement.SetMovement(!takingPhoto);
    }

    private void OnPictureTaken()
    {
        audioController.PlayCameraSnap();
    }

    public void OnGameOver()
    {
        movement.SetMovement(false);
        enemyCone.gameOver = true;
    }
}
