using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.AI;

public class EnemyMovement : MonoBehaviour
{
    [SerializeField]
    private NavMeshAgent navMeshAgent;

    [SerializeField]
    private Rigidbody2D enemyRigidbody;

    [SerializeField]
    private PlayerRenderer enemyRenderer;

    [SerializeField]
    private float spookedMoveSpeed = 10f;

    [SerializeField]
    private float newPointMaxDistance = 10f;

    private GameArea gameArea = null;
    //private EnemyRenderer enemyRenderer;

    // Start is called before the first frame update
    void Start()
    {
        gameArea = FindObjectOfType<GameArea>();

        navMeshAgent.updateRotation = false;
        navMeshAgent.updateUpAxis = false;
        navMeshAgent.enabled = false;

        MoveStraightToPosition(gameArea.transform.position);
    }

    // Update is called once per frame
    void Update()
    {
        // Rotate to face destination
        enemyRenderer.SetDirection(enemyRigidbody.velocity);

        // If we reached our destination, randomly pick a new one.
        if (navMeshAgent.isActiveAndEnabled && IsAtTarget)
        {
            GenerateNewTargetInGameArea();
        }
    }

    public void GenerateNewTargetInGameArea()
    {
        // Randomly generate a point to move to in the game area.
        Bounds bounds = gameArea.gameCollider.bounds;
        float x = Random.Range(bounds.min.x, bounds.max.x);
        float y = Random.Range(bounds.min.y, bounds.max.y);

        Vector2 position = new Vector2(x, y);
        NavMeshHit hit;
        NavMesh.SamplePosition(position, out hit, newPointMaxDistance, 1);
        PathToPosition(position);
    }

    public void SetMovement(bool enableMovement)
    {
        navMeshAgent.enabled = enableMovement;
    }

    public void PathToPosition(Vector2 position)
    {
        enemyRigidbody.velocity = new Vector2(0, 0);
        navMeshAgent.enabled = true;
        navMeshAgent.destination = position;
    }

    // Deactivate normal movement and just move to position
    public void MoveStraightToPosition(Vector3 position)
    {
        Vector2 newDirection = position - transform.position;
        newDirection = newDirection.normalized * navMeshAgent.speed;

        navMeshAgent.enabled = false;
        enemyRigidbody.velocity = newDirection;
    }

    // Deactivate normal movement and just move away from spookPosition fast
    public void RunAway(Vector3 spookPosition)
    {
        Vector2 newDirection = transform.position - spookPosition;
        newDirection = newDirection.normalized * spookedMoveSpeed;

        navMeshAgent.enabled = false;
        enemyRigidbody.velocity = newDirection;
    }

    private bool IsAtTarget
    {
        get
        {
            return !navMeshAgent.pathPending && navMeshAgent.remainingDistance < navMeshAgent.stoppingDistance;
        }
    }

    // In editor, draw a line to target position
    private void OnDrawGizmos()
    {
        Gizmos.color = Color.blue;
        Gizmos.DrawSphere(navMeshAgent.destination, 0.5f);

        Gizmos.color = Color.blue;
        Gizmos.DrawLine(transform.position, navMeshAgent.destination);
    }

}
