using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Spawner : MonoBehaviour
{
    [SerializeField]
    private Collider2D spawnCollider = null;

    [SerializeField]
    private GameObject enemyPrefab = null;

    [SerializeField]
    private int startingSpawns = 3;

    [SerializeField]
    private float timeToSpawn = 10f;

    [SerializeField]
    private float timeToReduceSpawnTime = 30f;

    [SerializeField]
    private float SpawnTimeReduction = 0.8f;

    private float spawnTimer = 0;
    private float metaTimer = 0;

    private void Start()
    {
        for (int i = 0; i < startingSpawns; ++i)
        {
            SpawnEnemy();
        }
    }

    private void Update()
    {
        spawnTimer += Time.deltaTime;
        if (spawnTimer > timeToSpawn)
        {
            SpawnEnemy();
            spawnTimer = 0;
        }

        metaTimer += Time.deltaTime;
        if (metaTimer > timeToReduceSpawnTime)
        {
            timeToSpawn *= SpawnTimeReduction;
            metaTimer = 0;
        }
    }

    public void SpawnEnemy()
    {
        // Generate a spawn position
        Vector2 position = new Vector2(0, 0);

        // It needs to be along one side, so lock one value to an extreme
        int lockedValue = Random.Range(0, 2);
        int minOrMax = Random.Range(0, 2);

        if (minOrMax == 0)
        {
            position[lockedValue] = spawnCollider.bounds.min[lockedValue];
        }
        else
        {
            position[lockedValue] = spawnCollider.bounds.max[lockedValue];
        }
       
        // generate whatever for the other
        if (lockedValue == 0)
        {
            position.y = Random.Range(spawnCollider.bounds.min.y, spawnCollider.bounds.max.y);
        }
        else
        {
            position.x = Random.Range(spawnCollider.bounds.min.x, spawnCollider.bounds.max.x);
        }

        Instantiate(enemyPrefab, position, Quaternion.identity);
    }
}
