using System;
using System.Collections;
using UnityEngine;
using UnityEngine.SceneManagement;

public class VisionCone : MonoBehaviour
{
    // Sends whether it sees the player
    public event Action<bool> OnSeePlayerChange = null;
    public event Action OnPictureTaken = null;

    [SerializeField]
    private FillupCone fillupCone = null;

    [SerializeField]
    float timeToSeePlayer = 2f;

    [SerializeField]
    LayerMask layerMask = 0;

    private bool takingPhoto = false;
    public bool playerInCone = false;
    public bool gameOver = false;
    private float timer = 0;
    private PlayerMovementController player = null;

    // Update is called once per frame
    void Update()
    {
        if (takingPhoto && !gameOver)
        {
            // If see player, fill up cone
            timer += Time.deltaTime;
            fillupCone.SetFill(Mathf.Clamp(timer / timeToSeePlayer, 0, 1));

            if (timer > timeToSeePlayer)
            {
                takingPhoto = false;
                OnSeePlayerChange?.Invoke(takingPhoto);
                OnPictureTaken?.Invoke();

                // Raycast to make sure we can see player 
                Vector2 directionTo = player.transform.position - transform.position;
                RaycastHit2D hit = Physics2D.Raycast(transform.position, directionTo, Mathf.Infinity, layerMask);
                bool raycastHitPlayer = hit.collider != null && hit.collider.gameObject.GetComponent<PlayerMovementController>() != null;

                if (hit.collider != null)
                {
                    Debug.Log(hit.collider.gameObject.name);
                }

                if (playerInCone && raycastHitPlayer)
                {
                    // You got caught, go to game over screen after some time
                    StartCoroutine(GameOverCoroutine());
                }
                else
                {
                    timer = 0;
                    fillupCone.SetFill(timer);
                }
            }
        }
    }

    private void OnTriggerEnter2D(Collider2D collision)
    {
        PlayerMovementController collisionObject = collision.gameObject.GetComponent<PlayerMovementController>();
        if (collisionObject)
        {
            player = collisionObject;
            takingPhoto = true;
            playerInCone = true;
            OnSeePlayerChange?.Invoke(takingPhoto);
        }
    }

    private void OnTriggerExit2D(Collider2D collision)
    {
        playerInCone = false;
    }

    private IEnumerator GameOverCoroutine()
    {
        PlayerSpookController spookController = player.gameObject.GetComponent<PlayerSpookController>();
        if (spookController) { spookController.enabled = false; }
        GameCamera camera = FindObjectOfType<GameCamera>();
        if (camera) { camera.FadeToMonochrome(); }
        player.enabled = false;

        EnemyMain[] allEnemies = FindObjectsOfType<EnemyMain>();
        foreach (EnemyMain enemy in allEnemies)
        {
            enemy.OnGameOver();
        }

        yield return new WaitForSeconds(1);
        FindObjectOfType<ScoreTracker>().GameOver(FindObjectOfType<PlayerCurrencyController>().GetCurrency());
    }
}
