using UnityEngine;

public class GameCamera : MonoBehaviour
{
    [SerializeField]
    private Transform trackedObject = null;

    [SerializeField]
    private Animator animator = null;

    private Vector3 offset = new Vector3(0, 0, -10);
    private bool shaking = false;
    private bool gameOver = false;
    private float shakeTimer = 0;
    private float shakeLength = 0;

    private void FixedUpdate()
    {
        if (!gameOver)
        {
            transform.position = Vector3.Lerp(transform.position, trackedObject.position, 0.05f) + offset;
        }
    }

    public void FadeToMonochrome()
    {
        gameOver = true;
        animator.Play("CameraFadeToMonochrome");
    }

    private void UpdateShake()
    {
        if (shaking && !gameOver)
        {
            Vector3 shakePosition = Vector3.zero;
            shakePosition.x += Random.Range(-0.5f, 0.5f);
            shakePosition.y += Random.Range(-0.5f, 0.5f);
            transform.transform.Translate(shakePosition);

            shakeTimer += Time.deltaTime;
            if (shakeTimer > shakeLength)
            {
                shaking = false;
            }
        }
    }

    public void ToggleShake(float shakeTime)
    {
        shaking = true;
        shakeLength = shakeTime;
        shakeTimer = 0;
    }
}
