﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class PlayerMovementController : MonoBehaviour
{
    [SerializeField]
    private float dashSpeed = 10f;
    [SerializeField]
    private float dashLength = 0.25f;
    [SerializeField]
    private float dashCooldown = 1f;
    [SerializeField]
    private PlayerAudioController audioController = null;

    public bool dashing = false;
    private float dashLengthTimer = 0;
    private float dashCooldownTimer = 0;

    public float movementSpeed = 1f;

    PlayerRenderer playerRenderer;
    Rigidbody2D rbody;    

    private void Awake()
    {
        rbody = GetComponent<Rigidbody2D>();
        playerRenderer = GetComponentInChildren<PlayerRenderer>();
    }

    private void Update()
    {
        bool dashInput = Input.GetButtonDown("Dash");

        if (!dashing)
        {
            dashCooldownTimer -= Time.deltaTime;
            if (dashCooldownTimer <= dashCooldown && dashInput)
            {
                StartDashing();
            }
        }
        else
        {
            dashLengthTimer += Time.deltaTime;
            if (dashLengthTimer > dashLength)
            {
                StopDashing();
            }
        }
    }

    private void StartDashing()
    {
        dashing = true;
        dashLengthTimer = 0;
        audioController.PlayDash();
    }

    private void StopDashing()
    {
        dashing = false;
        dashCooldownTimer = dashCooldown;
    }

    // Update is called once per frame
    void FixedUpdate()
    {
        float horizontalInput = Input.GetAxisRaw("Horizontal");
        float verticalInput = Input.GetAxisRaw("Vertical");

        Vector2 currentPos = rbody.position;
        Vector2 inputVector = new Vector2(horizontalInput, verticalInput);
        inputVector = Vector2.ClampMagnitude(inputVector, 1);

        float speed = dashing ? dashSpeed : movementSpeed;
        Vector2 movement = inputVector * speed;

        Vector2 newPos = currentPos + movement * Time.fixedDeltaTime;
        playerRenderer.SetDirection(movement);
        rbody.MovePosition(newPos);
    }
}
